@@ -268,6 +268,8 @@ class Network:
         self.agent_td_list_dict = {}
         # key: zone id, value: node id list
         self.zone_to_nodes_dict = {}
+        # key: zone id, value: bin_index
+        self.zone_bin_index = {}
         self.node_label_cost = None
         self.node_predecessor = None
         self.link_predecessor = None
@@ -688,7 +690,7 @@ class ColumnVec:
 class AgentType:
 
     def __init__(self, id=0, type='p', name='passenger',
-                 vot=10, flow_type=0, pce=1, ffs=60):
+                 vot=10, flow_type=0, pce=1, ffs=60, use_link_ffs=True):
         """ default constructor """
         self.id = id
         self.type = type
@@ -697,6 +699,7 @@ class AgentType:
         self.flow_type = flow_type
         self.pce = pce
         self.ffs = ffs
+        self.use_link_ffs = use_link_ffs
 
     def get_id(self):
         return self.id
@@ -1022,6 +1025,9 @@ class AccessNetwork(Network):
         node = self.base.get_nodes()[node_seq_no]
         return node.coord_x, node.coord_y
 
+    def get_zone_bin_indices(self):
+        return self.base.zone_bin_index
+
     def set_target_mode(self, mode):
         """ set up the target mode for accessibility evaluation
 
@@ -1122,14 +1128,7 @@ class AccessNetwork(Network):
                     + link.get_toll() / max(SMALL_DIVISOR, vot) * 60
                 )
         else:
-            if at.get_type_str().startswith('p'):
-                for link in self.get_links():
-                    self.link_cost_array[link.get_seq_no()] = (
-                        link.get_free_flow_travel_time()
-                        + link.get_route_choice_cost()
-                        + link.get_toll() / max(SMALL_DIVISOR, vot) * 60
-                    )
-            else:
+            if not at.use_link_ffs:
                 ffs = at.get_free_flow_speed()
 
                 for link in self.get_links():
@@ -1138,6 +1137,13 @@ class AccessNetwork(Network):
                         + link.get_route_choice_cost()
                         + link.get_toll() / max(SMALL_DIVISOR, vot) * 60
                     )
+            else:
+                for link in self.get_links():
+                    self.link_cost_array[link.get_seq_no()] = (
+                        link.get_free_flow_travel_time()
+                        + link.get_route_choice_cost()
+                        + link.get_toll() / max(SMALL_DIVISOR, vot) * 60
+                    )
 
 
 class Assignment:
